@@ -1,45 +1,34 @@
-// Copyright (C) 2024-2025 Hibiki AI Limited <info@hibiki-ai.com>
-//
-// This file is part of secretbase.
-//
-// secretbase is free software: you can redistribute it and/or modify it under
-// the terms of the GNU General Public License as published by the Free Software
-// Foundation, either version 3 of the License, or (at your option) any later
-// version.
-//
-// secretbase is distributed in the hope that it will be useful, but WITHOUT ANY
-// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-// A PARTICULAR PURPOSE. See the GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License along with
-// secretbase. If not, see <https://www.gnu.org/licenses/>.
-
 // secretbase ------------------------------------------------------------------
 
 #include "secret.h"
 
 // secretbase - SipHash implementation -----------------------------------------
 
-//  This program is free software; you can redistribute it and/or modify it
-//  under the terms of the GNU Lesser General Public License as published
-//  by the Free Software Foundation; either version 2.1 of the License, or
-//  (at your option) any later version.
-//
-//  This program is distributed in the hope that it will be useful, but
-//  WITHOUT ANY WARRANTY; without even the implied warranty of
-//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-//  Lesser General Public License for more details.
-//
-//  You should have received a copy of the GNU Lesser General Public License
-//  along with this program; If not, see <http://www.gnu.org/licenses/>.
-//  
-//  COPYRIGHT: (ordered alphabetically)
-//  Copyright (C) 2015-2022 Red Hat, Inc.
-//
-//  AUTHORS: (ordered alphabetically)
-//    Daniele Nicolodi <daniele@grinta.net>
-//    David Rheinsberg <david.rheinsberg@gmail.com>
-//    Tom Gundersen <teg@jklm.no>
+/*  LICENSE:
+ This project is dual-licensed under both the Apache License, Version
+ 2.0, and the GNU Lesser General Public License, Version 2.1+.
+ 
+ AUTHORS-ASL:
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+ 
+ http://www.apache.org/licenses/LICENSE-2.0
+ 
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+ 
+ COPYRIGHT: (ordered alphabetically)
+ Copyright (C) 2015-2022 Red Hat, Inc.
+ 
+ AUTHORS: (ordered alphabetically)
+ Daniele Nicolodi <daniele@grinta.net>
+ David Rheinsberg <david.rheinsberg@gmail.com>
+ Tom Gundersen <teg@jklm.no>
+ */
 
 #include <stddef.h>
 #include <stdint.h>
